==> dartgl-0.0.9.tar.gz: lib/dartgl_sdl.dart <==
library dartgl_sdl;
import 'dart-ext:dartgl_sdl';

int SDL_WINDOW_FULLSCREEN = 0x00000001;         /**< fullscreen window */
int SDL_WINDOW_OPENGL = 0x00000002;             /**< window usable with OpenGL context */
int SDL_WINDOW_SHOWN = 0x00000004;              /**< window is visible */
int SDL_WINDOW_HIDDEN = 0x00000008;             /**< window is not visible */
int SDL_WINDOW_BORDERLESS = 0x00000010;         /**< no window decoration */
int SDL_WINDOW_RESIZABLE = 0x00000020;          /**< window can be resized */
int SDL_WINDOW_MINIMIZED = 0x00000040;          /**< window is minimized */
int SDL_WINDOW_MAXIMIZED = 0x00000080;          /**< window is maximized */
int SDL_WINDOW_INPUT_GRABBED = 0x00000100;      /**< window has grabbed input focus */
int SDL_WINDOW_INPUT_FOCUS = 0x00000200;        /**< window has input focus */
int SDL_WINDOW_MOUSE_FOCUS = 0x00000400;        /**< window has mouse focus */
int SDL_WINDOW_FULLSCREEN_DESKTOP = ( SDL_WINDOW_FULLSCREEN | 0x00001000 );
int SDL_WINDOW_FOREIGN = 0x00000800;            /**< window not created by SDL */

int SDL_GL_RED_SIZE = 0x00000000; 
int SDL_GL_GREEN_SIZE = 0x00000001;
int SDL_GL_BLUE_SIZE = 0x00000002;
int SDL_GL_ALPHA_SIZE = 0x00000003;
int SDL_GL_BUFFER_SIZE = 0x00000004;
int SDL_GL_DOUBLEBUFFER = 0x00000005;
int SDL_GL_DEPTH_SIZE = 0x00000006;
int SDL_GL_STENCIL_SIZE = 0x00000007;
int SDL_GL_ACCUM_RED_SIZE = 0x00000008;
int SDL_GL_ACCUM_GREEN_SIZE = 0x00000009;
int SDL_GL_ACCUM_BLUE_SIZE = 0x0000000A;
int SDL_GL_ACCUM_ALPHA_SIZE = 0x0000000B;
int SDL_GL_STEREO = 0x0000000C;
int SDL_GL_MULTISAMPLEBUFFERS = 0x0000000D;
int SDL_GL_MULTISAMPLESAMPLES = 0x0000000E;
int SDL_GL_ACCELERATED_VISUAL = 0x0000000F;
int SDL_GL_RETAINED_BACKING = 0x00000010;
int SDL_GL_CONTEXT_MAJOR_VERSION = 0x00000011;
int SDL_GL_CONTEXT_MINOR_VERSION = 0x00000012;
int SDL_GL_CONTEXT_EGL = 0x00000013;
int SDL_GL_CONTEXT_FLAGS = 0x00000014;
int SDL_GL_CONTEXT_PROFILE_MASK = 0x00000015;
int SDL_GL_SHARE_WITH_CURRENT_CONTEXT = 0x00000016;

int SDL_Init() native "SDL_Init";
Pointer SDL_CreateWindow(String title, int x, int y, int w, int h, int flags) native "SDL_CreateWindow";
void SDL_ShowWindow(Pointer window) native "SDL_ShowWindow";
void SDL_HideWindow(Pointer window) native "SDL_HideWindow";
int SDL_PollEvent(Event e) native "SDL_PollEvent";

Pointer SDL_GL_CreateContext(Pointer window) native "SDL_GL_CreateContext";
void SDL_GL_MakeCurrent(Pointer window, Pointer context) native "SDL_GL_MakeCurrent";
void SDL_GL_SwapWindow(Pointer window) native "SDL_GL_SwapWindow";
void SDL_GL_SetSwapInterval(int value) native "SDL_GL_SetSwapInterval";
void SDL_GL_SetAttribute(int attr, int value) native "SDL_GL_SetAttribute";

Pointer SDL_Test() native "SDL_Test";

class Event{
  int type;
}

class Pointer {
  int pointer;
  
  Pointer(){}
  Pointer.main(){}
}

==> dartgl-0.0.11.tar.gz: lib/dartgl_sdl.dart <==
library dartgl_sdl;
import 'dart-ext:dartgl_sdl';

int SDL_INIT_TIMER = 0x00000001;
int SDL_INIT_AUDIO =  0x00000010;
int SDL_INIT_VIDEO = 0x00000020;  /**< SDL_INIT_VIDEO implies SDL_INIT_EVENTS */
int SDL_INIT_JOYSTICK = 0x00000200;  /**< SDL_INIT_JOYSTICK implies SDL_INIT_EVENTS */
int SDL_INIT_HAPTIC = 0x00001000;
int SDL_INIT_GAMECONTROLLER = 0x00002000;  /**< SDL_INIT_GAMECONTROLLER implies SDL_INIT_JOYSTICK */
int SDL_INIT_EVENTS = 0x00004000;
int SDL_INIT_NOPARACHUTE = 0x00100000;  /**< Don't catch fatal signals */
int SDL_INIT_EVERYTHING  = SDL_INIT_TIMER | SDL_INIT_AUDIO | SDL_INIT_VIDEO | SDL_INIT_EVENTS |  
                SDL_INIT_JOYSTICK | SDL_INIT_HAPTIC | SDL_INIT_GAMECONTROLLER;

int SDL_WINDOW_FULLSCREEN = 0x00000001;         /**< fullscreen window */
int SDL_WINDOW_OPENGL = 0x00000002;             /**< window usable with OpenGL context */
int SDL_WINDOW_SHOWN = 0x00000004;              /**< window is visible */
int SDL_WINDOW_HIDDEN = 0x00000008;             /**< window is not visible */
int SDL_WINDOW_BORDERLESS = 0x00000010;         /**< no window decoration */
int SDL_WINDOW_RESIZABLE = 0x00000020;          /**< window can be resized */
int SDL_WINDOW_MINIMIZED = 0x00000040;          /**< window is minimized */
int SDL_WINDOW_MAXIMIZED = 0x00000080;          /**< window is maximized */
int SDL_WINDOW_INPUT_GRABBED = 0x00000100;      /**< window has grabbed input focus */
int SDL_WINDOW_INPUT_FOCUS = 0x00000200;        /**< window has input focus */
int SDL_WINDOW_MOUSE_FOCUS = 0x00000400;        /**< window has mouse focus */
int SDL_WINDOW_FULLSCREEN_DESKTOP = ( SDL_WINDOW_FULLSCREEN | 0x00001000 );
int SDL_WINDOW_FOREIGN = 0x00000800;            /**< window not created by SDL */

int SDL_GL_RED_SIZE = 0x00000000; 
int SDL_GL_GREEN_SIZE = 0x00000001;
int SDL_GL_BLUE_SIZE = 0x00000002;
int SDL_GL_ALPHA_SIZE = 0x00000003;
int SDL_GL_BUFFER_SIZE = 0x00000004;
int SDL_GL_DOUBLEBUFFER = 0x00000005;
int SDL_GL_DEPTH_SIZE = 0x00000006;
int SDL_GL_STENCIL_SIZE = 0x00000007;
int SDL_GL_ACCUM_RED_SIZE = 0x00000008;
int SDL_GL_ACCUM_GREEN_SIZE = 0x00000009;
int SDL_GL_ACCUM_BLUE_SIZE = 0x0000000A;
int SDL_GL_ACCUM_ALPHA_SIZE = 0x0000000B;
int SDL_GL_STEREO = 0x0000000C;
int SDL_GL_MULTISAMPLEBUFFERS = 0x0000000D;
int SDL_GL_MULTISAMPLESAMPLES = 0x0000000E;
int SDL_GL_ACCELERATED_VISUAL = 0x0000000F;
int SDL_GL_RETAINED_BACKING = 0x00000010;
int SDL_GL_CONTEXT_MAJOR_VERSION = 0x00000011;
int SDL_GL_CONTEXT_MINOR_VERSION = 0x00000012;
int SDL_GL_CONTEXT_EGL = 0x00000013;
int SDL_GL_CONTEXT_FLAGS = 0x00000014;
int SDL_GL_CONTEXT_PROFILE_MASK = 0x00000015;
int SDL_GL_SHARE_WITH_CURRENT_CONTEXT = 0x00000016;

int SDL_Init(int flags) native "SDL_Init";
int SDL_InitSubSystem(int flags) native "SDL_InitSubSystem";
void SDL_QuitSubSystem(int flags) native "SDL_QuitSubSystem";
int SDL_WasInit(int flags) native "SDL_WasInit";
void SDL_Quit() native "SDL_Quit";

Pointer SDL_CreateWindow(String title, int x, int y, int w, int h, int flags) native "SDL_CreateWindow";
void SDL_ShowWindow(Pointer window) native "SDL_ShowWindow";
void SDL_DestroyWindow(Pointer window) native "SDL_DestroyWindow";
void SDL_HideWindow(Pointer window) native "SDL_HideWindow";
void SDL_RaiseWindow(Pointer window) native "SDL_RaiseWindow";
void SDL_MaximizeWindow(Pointer window) native "SDL_MaximizeWindow";
void SDL_MinimizeWindow(Pointer window) native "SDL_MinimizeWindow";
void SDL_RestoreWindow(Pointer window) native "SDL_RestoreWindow";
int SDL_SetWindowFullscreen(Pointer window, int flags) native "SDL_SetWindowFullscreen";

int SDL_PollEvent(Event e) native "SDL_PollEvent";

Pointer SDL_GL_CreateContext(Pointer window) native "SDL_GL_CreateContext";
void SDL_GL_DeleteContext(Pointer context) native "SDL_GL_DeleteContext";
void SDL_GL_MakeCurrent(Pointer window, Pointer context) native "SDL_GL_MakeCurrent";
Pointer SDL_GL_GetCurrentContext() native "SDL_GL_GetCurrentContext";
Pointer SDL_GL_GetCurrentWindow() native "SDL_GL_GetCurrentWindow";
void SDL_GL_SwapWindow(Pointer window) native "SDL_GL_SwapWindow";
void SDL_GL_SetSwapInterval(int value) native "SDL_GL_SetSwapInterval";
int SDL_GL_GetSwapInterval() native "SDL_GL_GetSwapInterval";
void SDL_GL_SetAttribute(int attr, int value) native "SDL_GL_SetAttribute";

Pointer SDL_Test() native "SDL_Test";

class Event{
  int type;
}

class Pointer {
  int pointer;
  
  Pointer(){}
  Pointer.main(){}
}
